==> owncloud_4.0.1debian.orig.tar.bz2: owncloud-4.0.1debian.orig/apps/contacts/l10n/ia.php <==
<?php $TRANSLATIONS = array(
"Cannot add empty property." => "Non pote adder proprietate vacue.",
"No address books found." => "Nulle adressario trovate",
"No contacts found." => "Nulle contactos trovate.",
"Error adding addressbook." => "Error durante que il addeva le adressario.",
"Error activating addressbook." => "Error in activar adressario",
"Error loading image." => "Il habeva un error durante le cargamento del imagine.",
"Error saving temporary file." => "Error durante le scriptura in le file temporari",
"No file was uploaded" => "Nulle file esseva incargate.",
"Missing a temporary folder" => "Manca un dossier temporari",
"Contacts" => "Contactos",
"Addressbook not found." => "Adressario non trovate.",
"This is not your addressbook." => "Iste non es tu libro de adresses",
"Contact could not be found." => "Contacto non poterea esser legite",
"Address" => "Adresse",
"Telephone" => "Telephono",
"Email" => "E-posta",
"Organization" => "Organisation",
"Work" => "Travalio",
"Home" => "Domo",
"Mobile" => "Mobile",
"Text" => "Texto",
"Voice" => "Voce",
"Message" => "Message",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Pager",
"Internet" => "Internet",
"Contact" => "Contacto",
"Add Contact" => "Adder contacto",
"Addressbooks" => "Adressarios",
"New Address Book" => "Nove adressario",
"CardDav Link" => "Ligamine CardDav",
"Download" => "Discargar",
"Edit" => "Modificar",
"Delete" => "Deler",
"Download contact" => "Discargar contacto",
"Delete contact" => "Deler contacto",
"Nickname" => "Pseudonymo",
"Enter nickname" => "Inserer pseudonymo",
"Birthday" => "Anniversario",
"Groups" => "Gruppos",
"Edit groups" => "Modificar gruppos",
"Preferred" => "Preferite",
"Enter email address" => "Entrar un adresse de e-posta",
"Delete email address" => "Deler adresse de E-posta",
"Enter phone number" => "Entrar un numero de telephono",
"Delete phone number" => "Deler numero de telephono",
"View on map" => "Vider in un carta",
"Add notes here." => "Adder notas hic",
"Add field" => "Adder campo",
"Profile picture" => "Imagine de profilo",
"Phone" => "Phono",
"Note" => "Nota",
"Delete current photo" => "Deler photo currente",
"Edit current photo" => "Modificar photo currente",
"Upload new photo" => "Incargar nove photo",
"Select photo from ownCloud" => "Seliger photo ex ownCloud",
"Edit address" => "Modificar adresses",
"Type" => "Typo",
"PO Box" => "Cassa postal",
"Extended" => "Extendite",
"Street" => "Strata",
"City" => "Citate",
"Region" => "Region",
"Zipcode" => "Codice postal",
"Country" => "Pais",
"Edit categories" => "Modificar categorias",
"Add" => "Adder",
"Addressbook" => "Adressario",
"Hon. prefixes" => "Prefixos honorific",
"Miss" => "Senioretta",
"Mr" => "Sr.",
"Mrs" => "Sra.",
"Dr" => "Dr.",
"Given name" => "Nomine date",
"Additional names" => "Nomines additional",
"Family name" => "Nomine de familia",
"Hon. suffixes" => "Suffixos honorific",
"New Addressbook" => "Nove adressario",
"Edit Addressbook" => "Modificar adressario",
"Active" => "Active",
"Save" => "Salveguardar",
"Submit" => "Submitter",
"Cancel" => "Cancellar",
"Import a contacts file" => "Importar un file de contactos",
"Please choose the addressbook" => "Per favor selige le adressario",
"create a new addressbook" => "Crear un nove adressario",
"Name of new addressbook" => "Nomine del nove gruppo:",
"Import" => "Importar",
"Contacts imported successfully" => "Contactos importate con successo.",
"Close Dialog" => "Clauder dialogo",
"Import Addressbook" => "Importar adressario.",
"Add contact" => "Adder adressario",
"more info" => "plus info",
"iOS/OS X" => "iOS/OS X"
);

==> owncloud_4.5.5debian.orig.tar.bz2: owncloud-4.5.5debian.orig/apps/contacts/l10n/ia.php <==
<?php $TRANSLATIONS = array(
"No address books found." => "Nulle adressario trovate",
"No contacts found." => "Nulle contactos trovate.",
"Cannot add empty property." => "Non pote adder proprietate vacue.",
"Error saving temporary file." => "Error durante le scriptura in le file temporari",
"Error loading image." => "Il habeva un error durante le cargamento del imagine.",
"No file was uploaded" => "Nulle file esseva incargate.",
"Missing a temporary folder" => "Manca un dossier temporari",
"Contacts" => "Contactos",
"Download" => "Discargar",
"Edit" => "Modificar",
"Delete" => "Deler",
"Cancel" => "Cancellar",
"This is not your addressbook." => "Iste non es tu libro de adresses",
"Contact could not be found." => "Contacto non poterea esser legite",
"Work" => "Travalio",
"Home" => "Domo",
"Mobile" => "Mobile",
"Text" => "Texto",
"Voice" => "Voce",
"Message" => "Message",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Pager",
"Internet" => "Internet",
"Birthday" => "Anniversario",
"Contact" => "Contacto",
"Add Contact" => "Adder contacto",
"Import" => "Importar",
"Delete current photo" => "Deler photo currente",
"Edit current photo" => "Modificar photo currente",
"Upload new photo" => "Incargar nove photo",
"Select photo from ownCloud" => "Seliger photo ex ownCloud",
"Organization" => "Organisation",
"Nickname" => "Pseudonymo",
"Enter nickname" => "Inserer pseudonymo",
"Groups" => "Gruppos",
"Edit groups" => "Modificar gruppos",
"Preferred" => "Preferite",
"Enter email address" => "Entrar un adresse de e-posta",
"Delete email address" => "Deler adresse de E-posta",
"Enter phone number" => "Entrar un numero de telephono",
"Delete phone number" => "Deler numero de telephono",
"View on map" => "Vider in un carta",
"Add notes here." => "Adder notas hic",
"Add field" => "Adder campo",
"Phone" => "Phono",
"Email" => "E-posta",
"Address" => "Adresse",
"Note" => "Nota",
"Download contact" => "Discargar contacto",
"Delete contact" => "Deler contacto",
"Edit address" => "Modificar adresses",
"Type" => "Typo",
"PO Box" => "Cassa postal",
"Extended" => "Extendite",
"City" => "Citate",
"Region" => "Region",
"Zipcode" => "Codice postal",
"Country" => "Pais",
"Addressbook" => "Adressario",
"Hon. prefixes" => "Prefixos honorific",
"Miss" => "Senioretta",
"Mr" => "Sr.",
"Mrs" => "Sra.",
"Dr" => "Dr.",
"Given name" => "Nomine date",
"Additional names" => "Nomines additional",
"Family name" => "Nomine de familia",
"Hon. suffixes" => "Suffixos honorific",
"Import a contacts file" => "Importar un file de contactos",
"Please choose the addressbook" => "Per favor selige le adressario",
"create a new addressbook" => "Crear un nove adressario",
"Name of new addressbook" => "Nomine del nove gruppo:",
"Add contact" => "Adder adressario",
"more info" => "plus info",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Adressarios",
"New Address Book" => "Nove adressario",
"Save" => "Salveguardar"
);
